@@ -1,5 +1,5 @@
 /*
-    Qalculate (GTK+ UI)
+    Qalculate (GTK UI)
 
     Copyright (C) 2003-2007, 2008, 2016-2020  Hanna Knutsson (hanna.knutsson@protonmail.com)
 
@@ -138,9 +138,14 @@ enum {
 	SHORTCUT_TYPE_SAVE_IMAGE,
 	SHORTCUT_TYPE_HELP,
 	SHORTCUT_TYPE_QUIT,
-	SHORTCUT_TYPE_CHAIN_MODE
+	SHORTCUT_TYPE_CHAIN_MODE,
+	SHORTCUT_TYPE_ALWAYS_ON_TOP,
+	SHORTCUT_TYPE_DO_COMPLETION,
+	SHORTCUT_TYPE_ACTIVATE_FIRST_COMPLETION
 };
 
+#define LAST_SHORTCUT_TYPE SHORTCUT_TYPE_ACTIVATE_FIRST_COMPLETION
+
 struct keyboard_shortcut {
 	guint key;
 	guint modifier;
@@ -433,6 +438,12 @@ void on_preferences_radiobutton_digit_grouping_locale_toggled(GtkToggleButton *w
 void on_preferences_button_result_font_toggled(GtkButton *w, gpointer user_data);
 void on_preferences_button_expression_font_toggled(GtkButton *w, gpointer user_data);
 void on_preferences_button_status_font_toggled(GtkButton *w, gpointer user_data);
+void on_preferences_checkbutton_decimal_comma_toggled(GtkToggleButton *w, gpointer);
+void on_preferences_checkbutton_dot_as_separator_toggled(GtkToggleButton *w, gpointer);
+void on_preferences_checkbutton_comma_as_separator_toggled(GtkToggleButton *w, gpointer);
+void on_preferences_radiobutton_temp_rel_toggled(GtkToggleButton *w, gpointer);
+void on_preferences_radiobutton_temp_abs_toggled(GtkToggleButton *w, gpointer);
+void on_preferences_radiobutton_temp_hybrid_toggled(GtkToggleButton *w, gpointer);
 void on_units_togglebutton_from_toggled(GtkToggleButton *togglebutton, gpointer user_data);
 void on_units_button_convert_clicked(GtkButton *button, gpointer user_data);
 void on_units_togglebutton_to_toggled(GtkToggleButton *togglebutton, gpointer user_data);
