@@ -1,5 +1,5 @@
 /*
-    Qalculate (GTK+ UI)
+    Qalculate (GTK UI)
 
     Copyright (C) 2003-2007, 2008, 2016  Hanna Knutsson (hanna.knutsson@protonmail.com)
 
@@ -139,10 +139,12 @@ void destroy_systray_icon();
 #endif
 bool has_systray_icon();
 void test_border(void);
+void update_colors(bool initial = false);
 void set_custom_buttons(void);
 void update_custom_buttons(int index = -1);
 void update_custom_buttons_edit(int index = -1, bool update_label_entry = true);
 void create_button_menus(void);
+void update_button_padding(bool initial = false);
 void create_main_window(void);
 GtkWidget* get_functions_dialog(void);
 GtkWidget* get_variables_dialog(void);
