@@ -1,5 +1,5 @@
 /*
-    Qalculate (GTK+ UI)
+    Qalculate (GTK UI)
 
     Copyright (C) 2003-2007, 2008, 2016-2021  Hanna Knutsson (hanna.knutsson@protonmail.com)
 
@@ -77,7 +77,7 @@ GtkBuilder *periodictable_builder, *simplefunctionedit_builder, *percentage_buil
 Thread *view_thread, *command_thread;
 string calc_arg, file_arg;
 
-bool do_timeout, check_expression_position;
+bool check_expression_position;
 gint expression_position;
 bool do_imaginary_j = false;
 
@@ -242,6 +242,15 @@ void create_application(GtkApplication *app) {
 	vans[2] = (KnownVariable*) CALCULATOR->addVariable(new KnownVariable(CALCULATOR->temporaryCategory(), ans_str + "3", m_undefined, _("Answer 3"), false));
 	vans[3] = (KnownVariable*) CALCULATOR->addVariable(new KnownVariable(CALCULATOR->temporaryCategory(), ans_str + "4", m_undefined, _("Answer 4"), false));
 	vans[4] = (KnownVariable*) CALCULATOR->addVariable(new KnownVariable(CALCULATOR->temporaryCategory(), ans_str + "5", m_undefined, _("Answer 5"), false));
+	if(ans_str != "ans") {
+		ans_str = "ans";
+		vans[0]->addName(ans_str);
+		vans[0]->addName(ans_str + "1");
+		vans[1]->addName(ans_str + "2");
+		vans[2]->addName(ans_str + "3");
+		vans[3]->addName(ans_str + "4");
+		vans[4]->addName(ans_str + "5");
+	}
 	v_memory = new KnownVariable(CALCULATOR->temporaryCategory(), "", m_zero, _("Memory"), true, true);
 	ExpressionName ename;
 	ename.name = "MR";
@@ -289,7 +298,6 @@ void create_application(GtkApplication *app) {
 	pixbuf_result = NULL;
 
 	//check for calculation errros regularly
-	do_timeout = true;
 	g_timeout_add_seconds(1, on_display_errors_timeout, NULL);
 
 	check_expression_position = true;
@@ -485,6 +493,20 @@ static gint qalculate_command_line(GtkApplication *app, GApplicationCommandLine
 	return 0;
 }
 
+#ifdef _WIN32
+#	include <winsock2.h>
+#	include <windows.h>
+#	include <shlobj.h>
+#	include <direct.h>
+#	include <knownfolders.h>
+#	include <initguid.h>
+#	include <shlobj.h>
+#	include <unordered_set>
+#	include <sys/types.h>
+#	include <sys/stat.h>
+#	include <dirent.h>
+using std::unordered_set;
+#endif
 
 int main (int argc, char *argv[]) {
 
@@ -527,6 +549,37 @@ int main (int argc, char *argv[]) {
 
 	g_object_unref(app);
 
+#ifdef _WIN32
+	char path[MAX_PATH];
+	SHGetFolderPathA(NULL, CSIDL_LOCAL_APPDATA | CSIDL_FLAG_CREATE, NULL, 0, path);
+	string tmpdir = buildPath(path, "Temp"), str, newest_file;
+	unordered_set<string> tmpfiles;
+	struct dirent *ep;
+	struct stat stats;
+	time_t newest_time = 0;
+	DIR *dp = opendir(tmpdir.c_str());
+	if(dp) {
+		while((ep = readdir(dp))) {
+			str = ep->d_name;
+			if(str.find("gdbus-nonce-file-") == 0) {
+				str = buildPath(tmpdir, str);
+				if(stat(str.c_str(), &stats) == 0) {
+					if(stats.st_mtime > newest_time) {
+						newest_time = stats.st_mtime;
+						newest_file = str;
+					}
+					tmpfiles.insert(str);
+				}
+			}
+		}
+		closedir(dp);
+		if(!newest_file.empty()) tmpfiles.erase(newest_file);
+		for(unordered_set<string>::iterator it = tmpfiles.begin(); it != tmpfiles.end(); ++it) {
+			remove(it->c_str());
+		}
+	}
+#endif
+
 	return status;
 
 }
